==> 1.1.2%2B1.tar.gz: lib/src/schema/schemas.dart <==
import 'all.dart';

class Schemas {
  static final all = {
    AlignmentSchema.id: AlignmentSchema.schema,
    AppBarThemeSchema.id: AppBarThemeSchema.schema,
    AxisSchema.id: AxisSchema.schema,
    BlendModeSchema.id: BlendModeSchema.schema,
    BorderRadiusSchema.id: BorderRadiusSchema.schema,
    BorderSideSchema.id: BorderSideSchema.schema,
    BorderStyleSchema.id: BorderStyleSchema.schema,
    BottomAppBarThemeScheme.id: BottomAppBarThemeScheme.schema,
    BottomNavigationBarTypeSchema.id: BottomNavigationBarTypeSchema.schema,
    BottomSheetThemeDataSchema.id: BottomSheetThemeDataSchema.schema,
    BoxBorderSchema.id: BoxBorderSchema.schema,
    BoxConstraintsSchema.id: BoxConstraintsSchema.schema,
    BoxDecorationSchema.id: BoxDecorationSchema.schema,
    BoxFitSchema.id: BoxFitSchema.schema,
    BoxShadowSchema.id: BoxShadowSchema.schema,
    BoxShapeSchema.id: BoxShapeSchema.schema,
    BrightnessSchema.id: BrightnessSchema.schema,
    ButtonBarLayoutBehaviorSchema.id: ButtonBarLayoutBehaviorSchema.schema,
    ButtonBarThemeDataSchema.id: ButtonBarThemeDataSchema.schema,
    ButtonTextThemeSchema.id: ButtonTextThemeSchema.schema,
    ButtonThemeDataSchema.id: ButtonThemeDataSchema.schema,
    CardThemeSchema.id: CardThemeSchema.schema,
    ChipThemeDataSchema.id: ChipThemeDataSchema.schema,
    ClipSchema.id: ClipSchema.schema,
    ColorSchema.id: ColorSchema.schema,
    ColorSchemeSchema.id: ColorSchemeSchema.schema,
    CrossAxisAlignmentSchema.id: CrossAxisAlignmentSchema.schema,
    CupertinoTextThemeDataSchema.id: CupertinoTextThemeDataSchema.schema,
    CupertinoThemeDataSchema.id: CupertinoThemeDataSchema.schema,
    DialogThemeSchema.id: DialogThemeSchema.schema,
    DividerThemeDataSchema.id: DividerThemeDataSchema.schema,
    DragStartBehaviorSchema.id: DragStartBehaviorSchema.schema,
    EdgeInsetsGeometrySchema.id: EdgeInsetsGeometrySchema.schema,
    FilterQualitySchema.id: FilterQualitySchema.schema,
    FlexFitSchema.id: FlexFitSchema.schema,
    FloatingActionButtonAnimatorSchema.id:
        FloatingActionButtonAnimatorSchema.schema,
    FloatingActionButtonLocationSchema.id:
        FloatingActionButtonLocationSchema.schema,
    FloatingActionButtonThemeDataSchema.id:
        FloatingActionButtonThemeDataSchema.schema,
    FloatingLabelBehaviorSchema.id: FloatingLabelBehaviorSchema.schema,
    FontFeatureSchema.id: FontFeatureSchema.schema,
    FontStyleSchema.id: FontStyleSchema.schema,
    FontWeightSchema.id: FontWeightSchema.schema,
    GradientSchema.id: GradientSchema.schema,
    GradientTransformSchema.id: GradientTransformSchema.schema,
    HitTestBehaviorSchema.id: HitTestBehaviorSchema.schema,
    IconDataSchema.id: IconDataSchema.schema,
    IconThemeDataSchema.id: IconThemeDataSchema.schema,
    ImageRepeatSchema.id: ImageRepeatSchema.schema,
    InputBorderSchema.id: InputBorderSchema.schemas,
    InputDecorationThemeSchema.id: InputDecorationThemeSchema.schema,
    InteractiveInkFeatureFactorySchema.id:
        InteractiveInkFeatureFactorySchema.schema,
    LocaleSchema.id: LocaleSchema.schema,
    MainAxisAlignmentSchema.id: MainAxisAlignmentSchema.schema,
    MainAxisSizeSchema.id: MainAxisSizeSchema.schema,
    MaterialBannerThemeDataSchema.id: MaterialBannerThemeDataSchema.schema,
    MaterialColorSchema.id: MaterialColorSchema.schema,
    MaterialTapTargetSizeSchema.id: MaterialTapTargetSizeSchema.schema,
    MaterialTypeSchema.id: MaterialTypeSchema.schema,
    Matrix4Schema.id: Matrix4Schema.schema,
    NavigationRailLabelTypeSchema.id: NavigationRailLabelTypeSchema.schema,
    NavigationRailThemeDataSchema.id: NavigationRailThemeDataSchema.schema,
    NotchedShapeSchema.id: NotchedShapeSchema.schema,
    OffsetSchema.id: OffsetSchema.schema,
    OverflowSchema.id: OverflowSchema.schema,
    PopupMenuThemeDataSchema.id: PopupMenuThemeDataSchema.schema,
    RadiusSchema.id: RadiusSchema.schema,
    RangeSliderThumbShapeSchema.id: RangeSliderThumbShapeSchema.schema,
    RangeSliderTickMarkShapeSchema.id: RangeSliderTickMarkShapeSchema.schema,
    RangeSliderTrackShapeSchema.id: RangeSliderTrackShapeSchema.schema,
    RangeSliderValueIndicatorShapeSchema.id:
        RangeSliderValueIndicatorShapeSchema.schema,
    RectSchema.id: RectSchema.schema,
    ScrollPhysicsSchema.id: ScrollPhysicsSchema.schema,
    ShadowSchema.id: ShadowSchema.schema,
    ShapeBorderSchema.id: ShapeBorderSchema.schema,
    ShowValueIndicatorSchema.id: ShowValueIndicatorSchema.schema,
    SliderComponentShapeSchema.id: SliderComponentShapeSchema.schema,
    SliderThemeDataSchema.id: SliderThemeDataSchema.schema,
    SliderTrackShapeSchema.id: SliderTrackShapeSchema.schema,
    SmartDashesTypeSchema.id: SmartDashesTypeSchema.schema,
    SmartQuotesTypeSchema.id: SmartQuotesTypeSchema.schema,
    SnackBarBehaviorSchema.id: SnackBarBehaviorSchema.schema,
    SnackBarThemeDataSchema.id: SnackBarThemeDataSchema.schema,
    StackFitSchema.id: StackFitSchema.schema,
    StrutStyleSchema.id: StrutStyleSchema.schema,
    TabBarIndicatorSizeSchema.id: TabBarIndicatorSizeSchema.schema,
    TabBarThemeSchema.id: TabBarThemeSchema.schema,
    TargetPlatformSchema.id: TargetPlatformSchema.schema,
    TextAlignSchema.id: TextAlignSchema.schema,
    TextAlignVerticalSchema.id: TextAlignVerticalSchema.schema,
    TextBaselineSchema.id: TextBaselineSchema.schema,
    TextCapitalizationSchema.id: TextCapitalizationSchema.schema,
    TextDecorationSchema.id: TextDecorationSchema.schema,
    TextDecorationStyleSchema.id: TextDecorationStyleSchema.schema,
    TextDirectionSchema.id: TextDirectionSchema.schema,
    TextHeightBehaviorSchema.id: TextHeightBehaviorSchema.schema,
    TextInputActionSchema.id: TextInputActionSchema.schema,
    TextInputTypeSchema.id: TextInputTypeSchema.schema,
    TextOverflowSchema.id: TextOverflowSchema.schema,
    TextStyleSchema.id: TextStyleSchema.schema,
    TextThemeSchema.id: TextThemeSchema.schema,
    TextWidthBasisSchema.id: TextWidthBasisSchema.schema,
    ThemeDataSchema.id: ThemeDataSchema.schema,
    TileModeSchema.id: TileModeSchema.schema,
    ToggleButtonsThemeDataSchema.id: ToggleButtonsThemeDataSchema.schema,
    ToolbarOptionsSchema.id: ToolbarOptionsSchema.schema,
    TooltipThemeDataSchema.id: TooltipThemeDataSchema.schema,
    TypographySchema.id: TypographySchema.schema,
    VerticalDirectionSchema.id: VerticalDirectionSchema.schema,
    VisualDensitySchema.id: VisualDensitySchema.schema,
  };
}

==> 2.0.0%2B1.tar.gz: lib/src/schema/schemas.dart <==
import 'all.dart';

class Schemas {
  static final all = {
    AlignmentSchema.id: AlignmentSchema.schema,
    AppBarThemeSchema.id: AppBarThemeSchema.schema,
    AutovalidateModeSchema.id: AutovalidateModeSchema.schema,
    AxisSchema.id: AxisSchema.schema,
    BlendModeSchema.id: BlendModeSchema.schema,
    BorderRadiusSchema.id: BorderRadiusSchema.schema,
    BorderSideSchema.id: BorderSideSchema.schema,
    BorderStyleSchema.id: BorderStyleSchema.schema,
    BottomAppBarThemeScheme.id: BottomAppBarThemeScheme.schema,
    BottomNavigationBarThemeDataSchema.id:
        BottomNavigationBarThemeDataSchema.schema,
    BottomNavigationBarTypeSchema.id: BottomNavigationBarTypeSchema.schema,
    BottomSheetThemeDataSchema.id: BottomSheetThemeDataSchema.schema,
    BoxBorderSchema.id: BoxBorderSchema.schema,
    BoxConstraintsSchema.id: BoxConstraintsSchema.schema,
    BoxDecorationSchema.id: BoxDecorationSchema.schema,
    BoxFitSchema.id: BoxFitSchema.schema,
    BoxShadowSchema.id: BoxShadowSchema.schema,
    BoxShapeSchema.id: BoxShapeSchema.schema,
    BrightnessSchema.id: BrightnessSchema.schema,
    ButtonBarLayoutBehaviorSchema.id: ButtonBarLayoutBehaviorSchema.schema,
    ButtonBarThemeDataSchema.id: ButtonBarThemeDataSchema.schema,
    ButtonStyleSchema.id: ButtonStyleSchema.schema,
    ButtonTextThemeSchema.id: ButtonTextThemeSchema.schema,
    ButtonThemeDataSchema.id: ButtonThemeDataSchema.schema,
    CardThemeSchema.id: CardThemeSchema.schema,
    ChipThemeDataSchema.id: ChipThemeDataSchema.schema,
    ClipSchema.id: ClipSchema.schema,
    ColorSchema.id: ColorSchema.schema,
    ColorSchemeSchema.id: ColorSchemeSchema.schema,
    CrossAxisAlignmentSchema.id: CrossAxisAlignmentSchema.schema,
    CrossFadeStateSchema.id: CrossFadeStateSchema.schema,
    CupertinoTextThemeDataSchema.id: CupertinoTextThemeDataSchema.schema,
    CupertinoThemeDataSchema.id: CupertinoThemeDataSchema.schema,
    DataTableThemeDataSchema.id: DataTableThemeDataSchema.schema,
    DecorationImageSchema.id: DecorationImageSchema.schema,
    DecorationPositionSchema.id: DecorationPositionSchema.schema,
    DialogThemeSchema.id: DialogThemeSchema.schema,
    DividerThemeDataSchema.id: DividerThemeDataSchema.schema,
    DragStartBehaviorSchema.id: DragStartBehaviorSchema.schema,
    EdgeInsetsGeometrySchema.id: EdgeInsetsGeometrySchema.schema,
    ElevatedButtonThemeDataSchema.id: ElevatedButtonThemeDataSchema.schema,
    FilterQualitySchema.id: FilterQualitySchema.schema,
    FlexFitSchema.id: FlexFitSchema.schema,
    FloatingActionButtonAnimatorSchema.id:
        FloatingActionButtonAnimatorSchema.schema,
    FloatingActionButtonLocationSchema.id:
        FloatingActionButtonLocationSchema.schema,
    FloatingActionButtonThemeDataSchema.id:
        FloatingActionButtonThemeDataSchema.schema,
    FloatingLabelBehaviorSchema.id: FloatingLabelBehaviorSchema.schema,
    FontFeatureSchema.id: FontFeatureSchema.schema,
    FontStyleSchema.id: FontStyleSchema.schema,
    FontWeightSchema.id: FontWeightSchema.schema,
    GradientSchema.id: GradientSchema.schema,
    GradientTransformSchema.id: GradientTransformSchema.schema,
    HitTestBehaviorSchema.id: HitTestBehaviorSchema.schema,
    IconDataSchema.id: IconDataSchema.schema,
    IconThemeDataSchema.id: IconThemeDataSchema.schema,
    ImageProviderSchema.id: ImageProviderSchema.schema,
    ImageRepeatSchema.id: ImageRepeatSchema.schema,
    InputBorderSchema.id: InputBorderSchema.schema,
    InputDecorationThemeSchema.id: InputDecorationThemeSchema.schema,
    InteractiveInkFeatureFactorySchema.id:
        InteractiveInkFeatureFactorySchema.schema,
    LocaleSchema.id: LocaleSchema.schema,
    MainAxisAlignmentSchema.id: MainAxisAlignmentSchema.schema,
    MainAxisSizeSchema.id: MainAxisSizeSchema.schema,
    MaterialBannerThemeDataSchema.id: MaterialBannerThemeDataSchema.schema,
    MaterialColorSchema.id: MaterialColorSchema.schema,
    MaterialTapTargetSizeSchema.id: MaterialTapTargetSizeSchema.schema,
    MaterialTypeSchema.id: MaterialTypeSchema.schema,
    Matrix4Schema.id: Matrix4Schema.schema,
    MaxLengthEnforcementSchema.id: MaxLengthEnforcementSchema.schema,
    MouseCursorSchema.id: MouseCursorSchema.schemas,
    NavigationRailLabelTypeSchema.id: NavigationRailLabelTypeSchema.schema,
    NavigationRailThemeDataSchema.id: NavigationRailThemeDataSchema.schema,
    NotchedShapeSchema.id: NotchedShapeSchema.schema,
    OffsetSchema.id: OffsetSchema.schema,
    OutlinedBorderSchema.id: OutlinedBorderSchema.schema,
    OutlinedButtonThemeDataSchema.id: OutlinedButtonThemeDataSchema.schema,
    OverflowSchema.id: OverflowSchema.schema,
    PageTransitionsBuilderSchema.id: PageTransitionsBuilderSchema.schema,
    PageTransitionsThemeSchema.id: PageTransitionsThemeSchema.schema,
    PopupMenuThemeDataSchema.id: PopupMenuThemeDataSchema.schema,
    RadiusSchema.id: RadiusSchema.schema,
    RangeSliderThumbShapeSchema.id: RangeSliderThumbShapeSchema.schema,
    RangeSliderTickMarkShapeSchema.id: RangeSliderTickMarkShapeSchema.schema,
    RangeSliderTrackShapeSchema.id: RangeSliderTrackShapeSchema.schema,
    RangeSliderValueIndicatorShapeSchema.id:
        RangeSliderValueIndicatorShapeSchema.schema,
    RectSchema.id: RectSchema.schema,
    ScrollPhysicsSchema.id: ScrollPhysicsSchema.schema,
    ScrollViewKeyboardDismissBehaviorSchema.id:
        ScrollViewKeyboardDismissBehaviorSchema.schema,
    ShadowSchema.id: ShadowSchema.schema,
    ShapeBorderSchema.id: ShapeBorderSchema.schema,
    ShowValueIndicatorSchema.id: ShowValueIndicatorSchema.schema,
    SizeSchema.id: SizeSchema.schema,
    SliderComponentShapeSchema.id: SliderComponentShapeSchema.schema,
    SliderThemeDataSchema.id: SliderThemeDataSchema.schema,
    SliderTickMarkShapeSchema.id: SliderTickMarkShapeSchema.schema,
    SliderTrackShapeSchema.id: SliderTrackShapeSchema.schema,
    SmartDashesTypeSchema.id: SmartDashesTypeSchema.schema,
    SmartQuotesTypeSchema.id: SmartQuotesTypeSchema.schema,
    SnackBarBehaviorSchema.id: SnackBarBehaviorSchema.schema,
    SnackBarThemeDataSchema.id: SnackBarThemeDataSchema.schema,
    StackFitSchema.id: StackFitSchema.schema,
    StrutStyleSchema.id: StrutStyleSchema.schema,
    TabBarIndicatorSizeSchema.id: TabBarIndicatorSizeSchema.schema,
    TabBarThemeSchema.id: TabBarThemeSchema.schema,
    TargetPlatformSchema.id: TargetPlatformSchema.schema,
    TextAlignSchema.id: TextAlignSchema.schema,
    TextAlignVerticalSchema.id: TextAlignVerticalSchema.schema,
    TextBaselineSchema.id: TextBaselineSchema.schema,
    TextButtonThemeDataSchema.id: TextButtonThemeDataSchema.schema,
    TextCapitalizationSchema.id: TextCapitalizationSchema.schema,
    TextDecorationSchema.id: TextDecorationSchema.schema,
    TextDecorationStyleSchema.id: TextDecorationStyleSchema.schema,
    TextDirectionSchema.id: TextDirectionSchema.schema,
    TextHeightBehaviorSchema.id: TextHeightBehaviorSchema.schema,
    TextInputActionSchema.id: TextInputActionSchema.schema,
    TextInputTypeSchema.id: TextInputTypeSchema.schema,
    TextOverflowSchema.id: TextOverflowSchema.schema,
    TextSelectionThemeDataSchema.id: TextSelectionThemeDataSchema.schema,
    TextStyleSchema.id: TextStyleSchema.schema,
    TextThemeSchema.id: TextThemeSchema.schema,
    TextWidthBasisSchema.id: TextWidthBasisSchema.schema,
    ThemeDataSchema.id: ThemeDataSchema.schema,
    TileModeSchema.id: TileModeSchema.schema,
    TimePickerThemeDataSchema.id: TimePickerThemeDataSchema.schema,
    ToggleButtonsThemeDataSchema.id: ToggleButtonsThemeDataSchema.schema,
    ToolbarOptionsSchema.id: ToolbarOptionsSchema.schema,
    TooltipThemeDataSchema.id: TooltipThemeDataSchema.schema,
    TypographySchema.id: TypographySchema.schema,
    VerticalDirectionSchema.id: VerticalDirectionSchema.schema,
    VisualDensitySchema.id: VisualDensitySchema.schema,
  };
}
